@@ -1,12 +1,14 @@
 import argparse
-import chardet
 import codecs
-import sys
 import os
-import time
 import subprocess
+import sys
+import time
 from datetime import datetime
+from slugify import slugify
+import glob
 
+import chardet
 
 clean_up = [
     ".bar",
@@ -210,6 +212,78 @@ def define_latex_engine(args: argparse) -> str:
         return "xelatex"
 
 
+def slugify_files(path_to_watch: str):
+    """_summary_
+
+    Args:
+        path_to_watch (str): _description_
+    """
+    rename = False
+    for (root, dirs, file) in os.walk(path_to_watch):
+        for dir in dirs:
+            if (
+                ".git" not in root
+                and ".venv" not in root
+                and ".venv" not in dir
+                and ".git" not in dir
+                and "dist" not in dir
+                and "dist" not in root
+                and "latexcor" not in root
+                and "latexcor" not in dir
+            ):
+
+                # print(root, dir, slugify(dir))
+                # print(os.path.join(root, dir))
+                # print(os.path.join(root, slugify(dir)))
+                if os.path.join(root, dir) != os.path.join(root, slugify(dir)):
+                    print(f"Renommage de {dir} en {slugify(dir)} ?")
+                    entree = input("[O]ui, non par défaut: ")
+                    if entree.upper() == "O":
+                        print("renommage")
+                        rename = True
+                        os.rename(
+                            os.path.join(root, dir), os.path.join(root, slugify(dir))
+                        )
+    if rename:
+        print("Un ou plusieurs renommages de dossiers ont été effectués.")
+        print("Il est nécessaire de relancer le script pour terminer le renommage.")
+        print("Voulez-vous le relancer maintenant ?")
+        entree = input("[O]ui, non par défaut: ")
+        if entree.upper() == "O":
+            slugify_files(path_to_watch)
+    else:
+        print("Aucun dosssier à renommer")
+
+    for (root, dirs, files) in os.walk(path_to_watch):
+        for file in files:
+            if ".tex" in file or ".pdf" in file or ".ipybn" in file:
+                filename, file_extension = os.path.splitext(file)
+                if filename != slugify(filename):
+                    print(f"Renommer {file} en {slugify(filename) + file_extension} ?")
+
+                    # print(filename)
+                    # print(file_extension)
+                    # print(os.path.join(root, file))
+                    # print(os.path.join(root, slugify(filename) + file_extension))
+                    entree = input("[O]ui, non par défaut: ")
+                    if entree.upper() == "O":
+                        print("renommage")
+                        rename = True
+                        os.rename(
+                            os.path.join(root, file),
+                            os.path.join(root, slugify(filename) + file_extension),
+                        )
+
+    #             else:
+    #                 print("Pas renommage")
+
+    # path = path_to_watch + "//**//*.tex"
+    # print(path)
+
+    # for file in glob.iglob(path, recursive=True):
+    #     print(file)
+
+
 def main() -> None:
     path_to_watch = os.getcwd()
     parser = argparse.ArgumentParser(description="""Basic usage: latexcor""")
@@ -237,6 +311,12 @@ def main() -> None:
         default=False,
         help="convert .tex files to utf-8 encoding",
     )
+    parser.add_argument(
+        "--slugify",
+        action="store_true",
+        default=False,
+        help="slugify .tex files",
+    )
     args = parser.parse_args()
     if args.clean:
         print(f"Nettoyage du dossier: {path_to_watch}")
@@ -250,6 +330,8 @@ def main() -> None:
     elif args.utf8:
         print("Conversion utf-8")
         convert_utf8(path_to_watch)
+    elif args.slugify:
+        slugify_files(path_to_watch)
     else:
         latex_engine = define_latex_engine(args)
         watch(path_to_watch, latex_engine)
